/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: BUSL-1.1
 */

import { Model } from 'miragejs';

export default Model.extend({
  feature_flags: null,
});
